@@ -39,11 +39,16 @@ class PdpRepo:
         return policy
 
     def getPolicies(self, subjectUris:List[str], resourceUris:List[str]) -> List[Policy]:
-        prefixedUris = [
+        prefixedSubjectUris = [
+            f"{self.__policiesKeyPrefix}{subjectUri}"
+            for subjectUri in subjectUris
+        ]
+        prefixedResourceUris = [
             f"{self.__policiesKeyPrefix}{resourceUri}"
             for resourceUri in resourceUris
         ]
-        self.__logger.info(f"{prefixedUris=}")
+        self.__logger.info(f"{prefixedSubjectUris=}")
+        self.__logger.info(f"{prefixedResourceUris=}")
         policiesDict = PdpRepo.__DYNAMODB_RESOURCE.batch_get_item(
             RequestItems = {
                 self.__policiesTableName: {
@@ -51,12 +56,12 @@ class PdpRepo:
                         {
                             self.__policiesTableEntityUriFieldName: prefixedUri,
                             self.__policiesTablePolicyTypeFieldName: f"{self.__policiesKeyPrefix}{PolicyType.SUBJECT.value}"
-                        } for prefixedUri in prefixedUris
+                        } for prefixedUri in prefixedSubjectUris
                     ] + [
                         {
                             self.__policiesTableEntityUriFieldName: prefixedUri,
                             self.__policiesTablePolicyTypeFieldName: f"{self.__policiesKeyPrefix}{PolicyType.RESOURCE.value}"
-                        } for prefixedUri in prefixedUris
+                        } for prefixedUri in prefixedResourceUris
                     ]
                 }
             }
